@@ -95,6 +95,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     self.init_server_chooser()
     self.init_popcon()
     self.init_auto_update()
+    self.init_release_upgrades()
     self.show_auto_update_level()
     # Setup the key list
     self.init_keys()
@@ -145,6 +146,12 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     # nothing to do here, set up signal in show_distro()
     pass
 
+  def init_release_upgrades(self):
+    " setup the widgets that allow configuring the release upgrades "
+    i = self.get_release_upgrades_policy()
+    self.userinterface.combobox_release_upgrades.setCurrentIndex(i)
+    kapp.connect(self.userinterface.combobox_release_upgrades, SIGNAL("currentIndexChanged(int)"), self.on_combobox_release_upgrades_changed)
+
   def init_auto_update(self):
     """ Set up the widgets that allow to configure the update automation """
     # this maps the key (combo-box-index) to the auto-update-interval value
@@ -381,6 +388,11 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         SoftwareProperties.set_update_automation_level(self, softwareproperties.UPDATE_NOTIFY)
     self.set_modified_config()
 
+  def on_combobox_release_upgrades_changed(self, combobox):
+    """ set the release upgrades policy """
+    i = self.userinterface.combobox_release_upgrades.currentIndex()
+    self.set_release_upgrades_policy(i)
+
   def on_combobox_server_changed(self, combobox):
     """
     Replace the servers used by the main and update sources with
