@@ -20,11 +20,10 @@
 #  USA
 
 from threading import Thread
-from urllib2 import urlopen, Request, URLError
 import re
 import subprocess
 import apt_pkg
-from urlparse import urlparse
+import pycurl
 
 def expand_ppa_line(abrev, distro_codename):
     """ Convert an abbreviated ppa name of the form 'ppa:$name' to a
@@ -47,6 +46,12 @@ def expand_ppa_line(abrev, distro_codename):
         sourceslistd, ppa_owner, ppa_name, distro_codename)
     return (line, file)
 
+class CurlCallback:
+    def __init__(self):
+        self.contents = ''
+
+    def body_callback(self, buf):
+        self.contents = self.contents + buf
 
 class AddPPASigningKeyThread(Thread):
     " thread class for adding the signing key in the background "
@@ -70,9 +75,16 @@ class AddPPASigningKeyThread(Thread):
         try:
             # we ask for a JSON structure from lp_page, we could use
             # simplejson, but the format is simple enough for the regexp
-            req =  Request(lp_url)
-            req.add_header("Accept","application/json")
-            lp_page = urlopen(req).read()
+            callback = CurlCallback()
+            curl = pycurl.Curl()
+            curl.setopt(pycurl.SSL_VERIFYPEER, 1)
+            curl.setopt(pycurl.SSL_VERIFYHOST, 2)
+            curl.setopt(pycurl.WRITEFUNCTION, callback.body_callback)
+            curl.setopt(pycurl.URL, str(lp_url))
+            curl.setopt(pycurl.HTTPHEADER, ["Accept: application/json"])
+            curl.perform()
+            curl.close()
+            lp_page = callback.contents
             #print lp_page
             signing_key_fingerprint = re.findall(
                 '\"signing_key_fingerprint\": \"(\w*)\"', lp_page)
@@ -84,8 +96,8 @@ class AddPPASigningKeyThread(Thread):
                 ["apt-key", "adv", "--keyserver", "keyserver.ubuntu.com",
                  "--recv", signing_key_fingerprint[0]])
             return (res == 0)
-        except URLError, e:
-            print "Error reading %s: %s" % (lp_url, e)
+        except pycurl.error, e:
+            print "Error reading %s: %s" % (lp_url, e[1])
             return False
         except IOError, e:
             print "Error: can't find signing_key_fingerprint at %s" % lp_url
